PacketEncoder

Struct PacketEncoder 

pub struct PacketEncoder { /* private fields */ }

Implementations

Source

impl PacketEncoder

pub fn new() -> Self

pub fn append_bytes(&mut self, bytes: &[u8])

pub fn prepend_packet<P>(&mut self, pkt: &P) -> Result<()>
where P: Packet + Encode,

pub fn append_packet<P>(&mut self, pkt: &P) -> Result<()>
where P: Packet + Encode,

pub fn take(&mut self) -> BytesMut

Takes all the packets written so far and encrypts them if encryption is enabled.

pub fn clear(&mut self)

pub fn set_compression(&mut self, threshold: CompressionThreshold)

pub fn enable_encryption(&mut self, key: &[u8; 16])

Initializes the cipher with the given key. All future packets and any that have not been taken yet are encrypted.

Panics

Panics if encryption is already enabled.