pub struct PacketWriter<'a> {
pub buf: &'a mut Vec<u8>,
pub threshold: CompressionThreshold,
}Expand description
An implementor of WritePacket backed by a Vec mutable reference.
Packets are written by appending to the contained vec. If an error occurs while writing, the written bytes are truncated away.
Fields
buf: &'a mut Vec<u8>threshold: CompressionThresholdImplementations
Sourceimpl<'a> PacketWriter<'a>
impl<'a> PacketWriter<'a>
pub fn new(buf: &'a mut Vec<u8>, threshold: CompressionThreshold) -> Self